is_valid_pro_tools_session_file

Function is_valid_pro_tools_session_file 

pub fn is_valid_pro_tools_session_file(path: &Path) -> bool
Returns true if path is a regular file whose first bytes match the Pro Tools session format (same check for .ptx and .ptf).