open_read_connection

Function open_read_connection 

fn open_read_connection(
    db_path: &Path,
    cache_kib: i32,
    mmap_cap: i64,
) -> Result<(Connection, Arc<AtomicU64>), String>
Open a read-pool connection with a progress-handler query timeout. The returned Arc<AtomicU64> must be stored alongside the connection and reset (via reset_query_deadline) each time the connection is acquired from the pool.