migrate_json_string

Function migrate_json_string 

fn migrate_json_string(val: Value) -> Value
If a value is a string that looks like JSON array/object, parse it to native. Handles migration from old format where structured data was JSON-stringified.